summaryrefslogtreecommitdiff
path: root/include/driver
diff options
context:
space:
mode:
authorVijay Hiremath <vijay.p.hiremath@intel.com>2021-06-18 11:25:30 -0700
committerCommit Bot <commit-bot@chromium.org>2021-06-18 21:44:49 +0000
commitbbd967de266e4c615d3e34ed8ae5425f175bf7e0 (patch)
treebd057c18f3e82b75360210147f410389285fcb33 /include/driver
parent257acda4b812d01687710ac2565e60e8df203eb2 (diff)
downloadchrome-ec-bbd967de266e4c615d3e34ed8ae5425f175bf7e0.tar.gz
bb_retimer: cleanup: Change the power handler func name & params
Changed the power handler function name from bb_retimer_power_handle() to bb_retimer_power_enable() and on_off param to enable. BUG=none BRANCH=none TEST=make buildall -j Change-Id: Ifad4c71a5d76b4841ea369a991160e221c051ec5 Signed-off-by: Vijay Hiremath <vijay.p.hiremath@intel.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2973375 Reviewed-by: Abe Levkoy <alevkoy@chromium.org>
Diffstat (limited to 'include/driver')
-rw-r--r--include/driver/retimer/bb_retimer_public.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/driver/retimer/bb_retimer_public.h b/include/driver/retimer/bb_retimer_public.h
index 7d9832f4ea..78047d3f7c 100644
--- a/include/driver/retimer/bb_retimer_public.h
+++ b/include/driver/retimer/bb_retimer_public.h
@@ -28,17 +28,17 @@ extern struct bb_usb_control bb_controls[];
#endif
/**
* Handle the power state of BB retimer
*
* Define override function at board level if the platform specific changes
* are needed to handle the power state of BB retimer.
*
* @param me Pointer to USB mux
* @param on_off BB retimer state to be changed
*
* @return EC_SUCCESS, or non-zero on error.
*/
-__override_proto int bb_retimer_power_handle(const struct usb_mux *me,
- int on_off);
+__override_proto int bb_retimer_power_enable(const struct usb_mux *me,
+ bool enable);
#endif /* __CROS_EC_DRIVER_RETIMER_BB_RETIMER_PUBLIC_H */
@@ -28,17 +28,17 @@ extern struct bb_usb_control bb_controls[];
#endif
/**
- * Handle the power state of BB retimer
+ * Enable/disable the power state of BB retimer
*
* Define override function at board level if the platform specific changes
@@ -28,17 +28,17 @@ extern struct bb_usb_control bb_controls[];
*
* Define override function at board level if the platform specific changes
- * are needed to handle the power state of BB retimer.
+ * are needed to enable/disable the power state of BB retimer.
*
* @param me Pointer to USB mux
@@ -28,17 +28,17 @@ extern struct bb_usb_control bb_controls[];
*
* @param me Pointer to USB mux
- * @param on_off BB retimer state to be changed
+ * @param enable BB retimer power state to be changed
*
* @return EC_SUCCESS, or non-zero on error.